@@ -3,6 +3,7 @@ import io
 import json
 import pandas as pd
 import numpy as np
+import time
 
 from .api import ApiObject, api_post, api_get, api_delete
 from .common import upload_dataframe
@@ -50,10 +51,13 @@ class Model(ApiObject):
         """reloads model."""
         self.update(api_get(f'api/models/{self.model_id}'))
 
-    def deploy(self):
+    def deploy(self, wait = True):
         """
         Deploys model.
-        
+
+        Args:
+            wait: blocks until model has deployed if true.
+
         Raises:
             RuntimeError.
         """
@@ -62,12 +66,31 @@ class Model(ApiObject):
 
         self.update(api_post(f'api/models/{self.model_id}/deployment'))
 
-    def discharge(self):
-        """discharges model."""
+        if wait:
+            while self.status == 'pending_deployment':
+                time.sleep(30)
+                self.refresh()
+
+    def discharge(self, wait = False):
+        """
+        Discharges model.
+
+        Args:
+            wait: blocks until model has discharged if true.
+
+        Raises:
+            RuntimeError.
+        """
         if self.status != 'running':
             raise RuntimeError('status must be running')
+
         self.update(api_delete(f'api/models/{self.model_id}/deployment'))
 
+        if wait:
+            while self.status == 'pending_discharge':
+                time.sleep(30)
+                self.refresh()
+
     def prediction_update(self, prediction_id, actual):
         """
         Updating model.
