@@ -207,7 +207,7 @@ def extract_statics(obj):
             if not is_input_metatype(metatype, True):
                 raise ValidationError('invalid input metatype')
 
-        statics['input_metatypes'] = sorted(list(input_metatypes), key=lambda x: x.name)
+        statics['input_metatypes'] = sorted([x.name.lower() for x in input_metatypes])
 
         is_multioutput = obj.is_multioutput()
         if not isinstance(is_multioutput, bool):
@@ -220,8 +220,7 @@ def extract_statics(obj):
             if not is_classification_metatype(target_metatype):
                 raise ValidationError('invalid classification metatype')
 
-            statics['target_metatype'] = target_metatype
-
+            statics['target_metatype'] = target_metatype.name.lower()
 
     if issubclass(obj, TabularClassifier):
         prediction_methods = obj.prediction_methods()
